# bungie-d2-oauth [![Documentation Status][rtdl]][rtd] [![PyPI Version][ppi]][ppl]
[rtd]: https://bungie-d2-oauth.readthedocs.io/en/latest/?badge=latest
[rtdl]: https://readthedocs.org/projects/bungie-d2-oauth/badge/?version=latest&style=flat-square
[ppi]: http://img.shields.io/pypi/v/bungie-d2-oauth.svg?style=flat-square
[ppl]: https://pypi.python.org/pypi/bungie-d2-oauth/
This package will get auth tokens from Bungie for your application.

# Prerequisites

 - Python 3.5+
 - Flask
 - requests 2.20.0